@@ -431,6 +431,7 @@ ClassIdentifierPage::ClassIdentifierPage(QWidget* parent)
 
 ClassIdentifierPage::~ClassIdentifierPage()
 {
+    delete d->classid;
     delete d;
 }
 
@@ -583,6 +584,7 @@ LicensePage::~LicensePage()
     else
         kWarning() << "Attempted to save an invalid license number: " << index << ". Number of licenses:" << d->availableLicenses.size();
 
+    delete d->license;
     delete d;
 }
 
@@ -658,14 +660,14 @@ QString& LicensePage::readLicense(int licenseIndex)
         /* Add date, name and email to license text */
         licenseText.replace("<year>", QDate::currentDate().toString("yyyy"));
         QString developer("%1 <%2>");
-        KEMailSettings* emailSettings = new KEMailSettings();
-        QString name = emailSettings->getSetting(KEMailSettings::RealName);
+        KEMailSettings emailSettings;
+        QString name = emailSettings.getSetting(KEMailSettings::RealName);
         if (name.isEmpty())
         {
             name = "<copyright holder>";
         }
         developer = developer.arg(name);
-        QString email = emailSettings->getSetting(KEMailSettings::EmailAddress);
+        QString email = emailSettings.getSetting(KEMailSettings::EmailAddress);
         if (email.isEmpty())
         {
             email = "email"; //no < > as they are already through the email field
@@ -822,6 +824,7 @@ bool OutputPage::validatePage()
 
 OutputPage::~OutputPage()
 {
+    delete d->output;
     delete d;
 }
 
