@@ -21,15 +21,15 @@
 
 #include "language/duchain/identifier.h"
 #include "language/duchain/duchainpointer.h"
+#include "language/duchain/types/structuretype.h"
 
-#include <QtGui/QWizard>
-#include <KDE/KUrl>
+#include <KAssistantDialog>
+#include <KUrl>
 
 #include "../languageexport.h"
-#include <language/duchain/types/structuretype.h>
 
 class KLineEdit;
-class KUrl;
+class KTextEdit;
 
 namespace KDevelop {
 
@@ -39,13 +39,13 @@ class Context;
 class Declaration;
 class DocumentChangeSet;
 
-class KDEVPLATFORMLANGUAGE_EXPORT ClassIdentifierPage : public QWizardPage
+class KDEVPLATFORMLANGUAGE_EXPORT ClassIdentifierPage : public QWidget
 {
     Q_OBJECT
-    Q_PROPERTY(QStringList inheritance READ inheritanceList())
+    Q_PROPERTY(QStringList inheritance READ inheritanceList)
 
 public:
-    ClassIdentifierPage(QWizard* parent);
+    ClassIdentifierPage(QWidget* parent);
     virtual ~ClassIdentifierPage();
 
     /// Returns the line edit which contains the new class identifier.
@@ -56,11 +56,10 @@ public:
 
     /// Returns a list of inheritances for the new class
     QStringList inheritanceList() const;
-    
-    virtual bool validatePage();
 
 Q_SIGNALS:
     void inheritanceChanged();
+    void isValid(bool valid);
 
 public Q_SLOTS:
     /// Called when an inheritance is to be added.  To override in subclasses,
@@ -88,7 +87,7 @@ public Q_SLOTS:
      * To override in subclasses, don't call this implementation.
      */
     virtual void moveDownInheritance();
-    
+
     /**
      * Parses a parent class into a QualifiedIdentifier, the default implementation
      * Just returns the string converted to a QualifiedIdentifier
@@ -97,6 +96,7 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void checkMoveButtonState();
+    void checkIdentifier();
 
 private:
 
@@ -104,14 +104,15 @@ private:
 };
 
 //!@todo Add the name of the Author at the top of the license
-class KDEVPLATFORMLANGUAGE_EXPORT LicensePage : public QWizardPage
+class KDEVPLATFORMLANGUAGE_EXPORT LicensePage : public QWidget
 {
     Q_OBJECT
 
 public:
-    LicensePage(QWizard* parent);
+    LicensePage(QWidget* parent);
     virtual ~LicensePage();
-    
+
+    KTextEdit* licenseTextEdit();
     bool validatePage();
 
 public Q_SLOTS:
@@ -120,10 +121,11 @@ public Q_SLOTS:
 private:
     // data
     class LicensePagePrivate* const d;
-    
+
+    ///FIXME: ugly internal api, move to *Private
     // methods
     void        initializeLicenses();
-    QString &   readLicense(int licenseIndex);
+    QString&    readLicense(int licenseIndex);
     bool        saveLicense();
 };
 
@@ -134,96 +136,96 @@ private:
 class KDEVPLATFORMLANGUAGE_EXPORT ClassGenerator
 {
   public:
-    
+
     ClassGenerator();
     virtual ~ClassGenerator();
-      
+
     /**
      * Generate the actual DocumentChangeSet
      */
     virtual DocumentChangeSet generate() = 0;
-    
+
     /**
      * Remove all previous base classes
      */
     virtual void clearInheritance();
-    
+
     /**
      * Clear all in class declarations
      */
     void clearDeclarations();
-    
+
     /**
      * Add another base class, must be the pure identifier
-     * 
+     *
      * \return the current list of base classes
      */
-    virtual const QList<DeclarationPointer> & addBaseClass(const QString &);
-    
+    virtual QList<DeclarationPointer> addBaseClass(const QString&);
+
     /**
      * Add a declaration to insert to the new Class
      */
-    void addDeclaration(DeclarationPointer newDeclaration);
-    
+    void addDeclaration(const DeclarationPointer& newDeclaration);
+
     /**
      * @return All the current declarations for this class
      */
-    const QList<DeclarationPointer> declarations() const;
-    
+    QList<DeclarationPointer> declarations() const;
+
     /// \return The list of all of the inherited classes
-    const QList<DeclarationPointer> & inheritanceList() const;
+    QList<DeclarationPointer> inheritanceList() const;
 
     /// \return The list of directly inherited classes
-    const QList<DeclarationPointer> & directInheritanceList() const;
+    QList<DeclarationPointer> directInheritanceList() const;
 
     /**
      *Should return the suggested url of the header file for the given class-name
      */
-    virtual KUrl headerUrlFromBase(KUrl baseUrl, bool toLower=true);
+    virtual KUrl headerUrlFromBase(const KUrl& baseUrl, bool toLower = true);
 
     /**
      *Should return the suggested url of the implementation file for the given class-name,
      *if header and implementation are separate for this language.
      */
-    virtual KUrl implementationUrlFromBase(KUrl baseUrl, bool toLower=true);
-    
+    virtual KUrl implementationUrlFromBase(const KUrl& baseUrl, bool toLower = true);
+
     /**
      * Set the URL where the header will be implemented
      */
-    void setHeaderUrl(KUrl header);
-    
+    void setHeaderUrl(const KUrl& header);
+
     /**
      * Set the URL where the implementation will be implemented
      */
-    void setImplementationUrl(KUrl implementation);
-    
+    void setImplementationUrl(const KUrl& implementation);
+
     /**
      * Set the position where the header is to be inserted
      */
-    void setHeaderPosition(SimpleCursor position);
-    
+    void setHeaderPosition(const SimpleCursor& position);
+
     /**
      * Set the position where the implementation stubbs are to be inserted
      */
-    void setImplementationPosition(SimpleCursor position);
-    
+    void setImplementationPosition(const SimpleCursor& position);
+
     /**
      * \return The name of the class to generate (excluding namespaces)
      */
-    const QString & name() const;
-    
+    QString name() const;
+
     /**
      * \param identifier The Qualified identifier that the class will have
      */
-    virtual void setIdentifier(const QString & identifier);
-    
+    virtual void setIdentifier(const QString& identifier);
+
     /**
      * \return The Identifier of the class to generate (including all used namespaces)
      */
     virtual QString identifier() const;
-    
-    const QString & license() const;
-    void setLicense(const QString & license);
+
+    QString license() const;
+    void setLicense(const QString& license);
 
     /**
      * \return The class to be generated as a Type
@@ -231,95 +233,115 @@ class KDEVPLATFORMLANGUAGE_EXPORT ClassGenerator
     virtual StructureType::Ptr objectType() const = 0;
 
   protected:
-    
+
     /**
      * Set the name (without namespace) for this class
      */
-    void setName(const QString &);
-    
+    void setName(const QString&);
+
     SimpleCursor headerPosition();
     SimpleCursor implementationPosition();
-    
-    KUrl & headerUrl();
-    KUrl & implementationUrl();
-    
+
+    KUrl headerUrl();
+    KUrl implementationUrl();
+
     /**
      * Look recursively for parent classes, and add them to the Inheritance list
      */
     void fetchParentClasses(const Context * baseClass);
-    
+
     QList<DeclarationPointer> m_baseClasses;  //!< These are the base classes, that are directly inherited from
-    QList<DeclarationPointer> m_declarations; //!< Declarations 
-    
+    QList<DeclarationPointer> m_declarations; //!< Declarations
+
   private:
     struct ClassGeneratorPrivate * const d;
-    
-    void fetchSuperClasses(DeclarationPointer derivedClass);
+
+    ///FIXME: move to *Private
+    void fetchSuperClasses(const DeclarationPointer& derivedClass);
 };
 
 /**
- * Provides a wizard for creating a new class using a ClassGenerator.
+ * Provides an assistant for creating a new class using a ClassGenerator.
  */
-class KDEVPLATFORMLANGUAGE_EXPORT CreateClassWizard : public QWizard
+class KDEVPLATFORMLANGUAGE_EXPORT CreateClassAssistant : public KAssistantDialog
 {
     Q_OBJECT
 
 public:
-    CreateClassWizard(QWidget* parent, ClassGenerator * generator, KUrl baseUrl = KUrl());
-    virtual ~CreateClassWizard();
+    CreateClassAssistant(QWidget* parent, ClassGenerator * generator, const KUrl& baseUrl = KUrl());
+    virtual ~CreateClassAssistant();
     /**
-     * Creates the generic parts of the new class wizard.
+     * Creates the generic parts of the new class assistant.
      */
-    
     virtual void setup();
+
     /**
-     * Called when the wizard completes.
-     */
-    virtual void accept();
-    
-    /**
-     * \return The generator that this wizard will use
+     * \return The generator that this assistant will use
      */
     virtual ClassGenerator * generator();
 
     virtual ClassIdentifierPage* newIdentifierPage();
 
     virtual OverridesPage* newOverridesPage();
+
+public Q_SLOTS:
+    /**
+     * Called when the next button is clicked.
+     */
+    virtual void next();
+    /**
+     * Called when the assistant completes.
+     */
+    virtual void accept();
+
+private Q_SLOTS:
+    void checkClassIdentifierPage(bool valid);
+    void checkOutputPage(bool valid);
+
 private:
+    bool validateClassIdentifierPage();
+    bool validateOverridesPage();
+    bool validateLicensePage();
+    bool validateOutputPage();
+
     friend class OutputPage;
-    class CreateClassWizardPrivate* const d;
+    class CreateClassAssistantPrivate* const d;
 };
 
-class KDEVPLATFORMLANGUAGE_EXPORT OutputPage : public QWizardPage
+class KDEVPLATFORMLANGUAGE_EXPORT OutputPage : public QWidget
 {
     Q_OBJECT
 
 public:
-    OutputPage(CreateClassWizard* parent);
+    OutputPage(CreateClassAssistant* parent);
     virtual ~OutputPage();
 
     virtual void initializePage();
-    
+
     virtual bool validatePage();
 
     virtual bool isComplete() const;
+
+Q_SIGNALS:
+    void isValid(bool valid);
+
 private:
     class OutputPagePrivate* const d;
-    
+
 private Q_SLOTS:
     virtual void updateFileNames();
-    
+
     /**
      * This implementation simply enables the position widgets on a file that exists.
      * Derived classes should overload to set the ranges where class generation should be allowed
      */
-    virtual void updateHeaderRanges(const QString &);
-    
+    virtual void updateHeaderRanges(const QString&);
+
     /**
      * This implementation simply enables the position widgets on a file that exists.
      * Derived classes should overload to set the ranges where class generation should be allowed
      */
-    virtual void updateImplementationRanges(const QString &);
+    virtual void updateImplementationRanges(const QString&);
 };
 }
 
