@@ -18,6 +18,7 @@
 #include <QFileInfo>
 #include <QTextCodec>
 #include <QTextStream>
+#include <QDirIterator>
 
 #include <ktar.h>
 #include <kzip.h>
@@ -44,6 +45,7 @@
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iplugincontroller.h>
 #include <interfaces/iuicontroller.h>
+#include <interfaces/idocumentcontroller.h>
 #include <interfaces/context.h>
 #include <interfaces/contextmenuextension.h>
 #include <vcs/vcslocation.h>
@@ -101,13 +103,21 @@ void AppWizardPlugin::slotNewProject()
     m_templatesModel->refresh();
     AppWizardDialog dlg(core()->pluginController(), m_templatesModel);
 
-
     if (dlg.exec() == QDialog::Accepted)
     {
         QString project = createProject( dlg.appInfo() );
         if (!project.isEmpty())
         {
             core()->projectController()->openProject(KUrl::fromPath(project));
+
+            KConfig templateConfig(dlg.appInfo().appTemplate);
+            KConfigGroup general(&templateConfig, "General");
+            QString file = general.readEntry("ShowFilesAfterGeneration");
+            if (!file.isEmpty())
+            {
+                file = KMacroExpander::expandMacros(file, m_variables);
+                core()->documentController()->openDocument(file);
+            }
         } else {
             KMessageBox::error( KDevelop::ICore::self()->uiController()->activeMainWindow(), i18n("Could not create project from template\n"), i18n("Failed to create project") );
         }
@@ -317,6 +327,15 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
 
     QString projectFileName = QDir::cleanPath( dest.toLocalFile() + '/' + info.name + ".kdev4" );
 
+    // Loop through the new project directory and try to detect the first .kdev4 file.
+    // If one is found this file will be used. So .kdev4 file can be stored in any subdirectory and the
+    // project templates can be more complex.
+    QDirIterator it(QDir::cleanPath( dest.toLocalFile()), QStringList() << "*.kdev4", QDir::NoFilter, QDirIterator::Subdirectories);
+    if(it.hasNext() == true)
+    {
+        projectFileName = it.next();
+    }
+
     kDebug() << "Returning" << projectFileName << QFileInfo( projectFileName ).exists() ;
 
     if( ! QFileInfo( projectFileName ).exists() )
