@@ -14,7 +14,6 @@
 #include <QStandardItemModel>
 
 class AppWizardPlugin;
-class ProjectTemplateItem;
 
 class ProjectTemplatesModel: public QStandardItemModel {
 public:
@@ -27,7 +26,7 @@ public:
 private:
     void extractTemplateDescriptions();
     bool templateExists(const QString&);
-    ProjectTemplateItem *createItem(const QString &name, const QString &category);
+    QStandardItem *createItem(const QString &name, const QString &category);
 
     AppWizardPlugin *m_plugin;
 
