@@ -36,18 +36,40 @@ CvsProxy::~CvsProxy()
 {
 }
 
-bool CvsProxy::isValidDirectory(const KUrl & dirPath) const
+bool CvsProxy::isValidDirectory(KUrl dirPath) const
 {
-    QString path = dirPath.toLocalFile();
-    QFileInfo fsObject(path);
-    if (fsObject.isFile())
-        path = fsObject.path() + QDir::separator() + "CVS";
-    else
-        path = path + QDir::separator() + "CVS";
-    fsObject.setFile(path);
+    QFileInfo fsObject( dirPath.toLocalFile() );
+    if( !fsObject.isDir() )
+        dirPath.setFileName( QString() );
+
+    dirPath.addPath( "CVS" );
+    fsObject.setFile( dirPath.toLocalFile() );
     return fsObject.exists();
 }
 
+bool CvsProxy::isVersionControlled(KUrl filePath) const
+{
+    QFileInfo fsObject( filePath.toLocalFile() );
+    if( !fsObject.isDir() )
+        filePath.setFileName( QString() );
+
+    filePath.addPath( "CVS" );
+    QFileInfo cvsObject( filePath.toLocalFile() );
+    if( !cvsObject.exists() )
+        return false;
+
+    if( fsObject.isDir() )
+        return true;
+
+    filePath.addPath( "Entries" );
+    QFile cvsEntries( filePath.toLocalFile() );
+    cvsEntries.open( QIODevice::ReadOnly );
+    QString cvsEntriesData = cvsEntries.readAll();
+    cvsEntries.close();
+    return ( cvsEntriesData.indexOf( fsObject.fileName() ) != -1 );
+}
+
+
 bool CvsProxy::prepareJob(CvsJob* job, const QString& repository, enum RequestedOperation op)
 {
     // Only do this check if it's a normal operation like diff, log ...
