@@ -68,9 +68,8 @@ public:
             TerminalInterface* interface = qobject_cast<TerminalInterface*>(konsolepart);
             Q_ASSERT(interface);
 
-//             interface->startProgram( "/home/nolden/kdedev/install-mini/bin/kdevelop_attach", QStringList() << "-s" << KDevelop::ICore::self()->activeSession()->id().toString() );
             interface->showShellInDir( QString() );
-            interface->sendInput( "kdevelop_attach -s " + KDevelop::ICore::self()->activeSession()->id().toString() + "\n" );
+            interface->sendInput( "kdevelop! -s " + KDevelop::ICore::self()->activeSession()->id().toString() + '\n' );
             
         }else
         {
