@@ -17,13 +17,18 @@
 */
 
 #include "projectitemquickopen.h"
+
 #include <QIcon>
 #include <QTextBrowser>
-#include <klocale.h>
+
+#include <KLocalizedString>
+
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/idocumentcontroller.h>
-#include <language/interfaces/iquickopen.h>
 #include <interfaces/icore.h>
+
+#include <language/interfaces/iquickopen.h>
+
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/declaration.h>
@@ -33,45 +38,53 @@
 
 using namespace KDevelop;
 
-DUChainItemData::DUChainItemData( const DUChainItem& file, bool openDefinition ) : m_item(file), m_openDefinition(openDefinition) {
+DUChainItemData::DUChainItemData( const DUChainItem& file, bool openDefinition )
+: m_item(file)
+, m_openDefinition(openDefinition)
+{
 }
 
-QString DUChainItemData::text() const {
-  KDevelop::DUChainReadLocker lock( DUChain::lock() );
+QString DUChainItemData::text() const
+{
+  DUChainReadLocker lock;;
   Declaration* decl = m_item.m_item.data();
   if(!decl)
     return i18n("Not available any more: %1", m_item.m_text);
 
-  if(FunctionDefinition* def = dynamic_cast<FunctionDefinition*>(decl))
-      if(def->declaration())
-          decl = def->declaration();
-      
+  if(FunctionDefinition* def = dynamic_cast<FunctionDefinition*>(decl)) {
+    if(def->declaration()) {
+      decl = def->declaration();
+    }
+  }
+
   QString text = decl->qualifiedIdentifier().toString();
-  
+
   if(!decl->abstractType()) {
-      
-      //With simplified representation, still mark functions as such by adding parens
-      if(dynamic_cast<AbstractFunctionDeclaration*>(decl))
-          text += "(...)";
-      
-  }else{
-    TypePtr<FunctionType> function = decl->type<FunctionType>();
-    if( function )
-        text  += function->partToString( FunctionType::SignatureArguments );
+    //With simplified representation, still mark functions as such by adding parens
+    if(dynamic_cast<AbstractFunctionDeclaration*>(decl)) {
+      text += "(...)";
+    }
+  }else if(TypePtr<FunctionType> function = decl->type<FunctionType>()) {
+    text += function->partToString( FunctionType::SignatureArguments );
   }
 
   return text;
 }
 
-QList<QVariant> DUChainItemData::highlighting() const {
+QList<QVariant> DUChainItemData::highlighting() const
+{
+  DUChainReadLocker lock;;
 
-  KDevelop::DUChainReadLocker lock( DUChain::lock() );
   Declaration* decl = m_item.m_item.data();
-  if(!decl)
+  if(!decl) {
     return QList<QVariant>();
-  if(FunctionDefinition* def = dynamic_cast<FunctionDefinition*>(decl))
-      if(def->declaration())
-          decl = def->declaration();
+  }
+
+  if(FunctionDefinition* def = dynamic_cast<FunctionDefinition*>(decl)) {
+    if(def->declaration()) {
+      decl = def->declaration();
+    }
+  }
 
   QTextCharFormat boldFormat;
   boldFormat.setFontWeight(QFont::Bold);
@@ -81,15 +94,17 @@ QList<QVariant> DUChainItemData::highlighting() const {
 
   QString signature;
   TypePtr<FunctionType> function = decl->type<FunctionType>();
-  if(function)
+  if(function) {
     signature = function->partToString( FunctionType::SignatureArguments );
+  }
 
   //Only highlight the last part of the qualified identifier, so the scope doesn't distract too much
   QualifiedIdentifier id = decl->qualifiedIdentifier();
   QString fullId = id.toString();
   QString lastId;
-  if(!id.isEmpty())
-      lastId = id.last().toString();
+  if(!id.isEmpty()) {
+    lastId = id.last().toString();
+  }
 
   prefixLength += fullId.length() - lastId.length();
 
@@ -110,45 +125,49 @@ QList<QVariant> DUChainItemData::highlighting() const {
 
 }
 
-QString DUChainItemData::htmlDescription() const {
-  if(m_item.m_noHtmlDestription)
-      return QString();
-  KDevelop::DUChainReadLocker lock( DUChain::lock() );
+QString DUChainItemData::htmlDescription() const
+{
+  if(m_item.m_noHtmlDestription) {
+    return QString();
+  }
+
+  DUChainReadLocker lock;;
   Declaration* decl = m_item.m_item.data();
-  if(!decl)
+  if(!decl) {
     return i18n("Not available any more");
+  }
 
   TypePtr<FunctionType> function = decl->type<FunctionType>();
 
   QString text;
 
-  if( function && function->returnType() )
-    text  = i18n("Return:") + ' ' + function->partToString(FunctionType::SignatureReturn);
+  if( function && function->returnType() ) {
+    text = i18nc("%1: function signature", "Return: %1",
+                  function->partToString(FunctionType::SignatureReturn));
+  }
 
-  text += ' ' + i18n("File:") + ' ' + decl->url().str();
-//   TypePtr<FunctionType> function = decl->type<FunctionType>();
-//   if( function )
-//     text  = QString("%1 %2%3").arg(function->partToString( FunctionType::SignatureReturn)).arg(decl->identifier().toString()).arg(function->partToString( FunctionType::SignatureArguments ));
-//   else
-//     text = decl->toString();
+  text += ' ' + i18nc("%1: file path", "File: %1", decl->url().str());
 
-  QString ret = "<small><small>" + text;
+  QString ret = "<small><small>" + text + "</small></small>";
+
   if(!m_item.m_project.isEmpty()) {
-      ret = i18n("Project") + ' ' + m_item.m_project + (ret.isEmpty() ? ", " : "") + ret/*", " + i18n("path") + totalUrl().toLocalFile() +*/; //Show only the path because of limited space
+    ret.prepend(i18n("Project %1", m_item.m_project) + (ret.isEmpty() ? ", " : ""));
   }
 
-  ret += "</small></small>";
   return ret;
 }
 
-bool DUChainItemData::execute( QString& /*filterText*/ ) {
-  KDevelop::DUChainReadLocker lock( DUChain::lock() );
+bool DUChainItemData::execute( QString& /*filterText*/ )
+{
+  DUChainReadLocker lock;;
   Declaration* decl = m_item.m_item.data();
-  if(!decl)
+  if(!decl) {
     return false;
+  }
 
-  if(m_openDefinition && FunctionDefinition::definition(decl))
-      decl = FunctionDefinition::definition(decl);
+  if(m_openDefinition && FunctionDefinition::definition(decl)) {
+    decl = FunctionDefinition::definition(decl);
+  }
 
   KUrl url = KUrl(decl->url().str());
   KTextEditor::Cursor cursor = decl->rangeInCurrentRevision().textRange().start();
@@ -156,9 +175,10 @@ bool DUChainItemData::execute( QString& /*filterText*/ ) {
   DUContext* internal = decl->internalContext();
 
   if(internal && (internal->type() == DUContext::Other || internal->type() == DUContext::Class)) {
-      //Move into the body
-      if(internal->range().end.line > internal->range().start.line)
-        cursor = KTextEditor::Cursor(internal->range().start.line+1, 0); //Move into the body
+    //Move into the body
+    if(internal->range().end.line > internal->range().start.line) {
+      cursor = KTextEditor::Cursor(internal->range().start.line+1, 0); //Move into the body
+    }
   }
 
   lock.unlock();
@@ -166,39 +186,59 @@ bool DUChainItemData::execute( QString& /*filterText*/ ) {
   return true;
 }
 
-bool DUChainItemData::isExpandable() const {
+bool DUChainItemData::isExpandable() const
+{
   return true;
 }
 
-QWidget* DUChainItemData::expandingWidget() const {
-  KDevelop::DUChainReadLocker lock( DUChain::lock() );
+QWidget* DUChainItemData::expandingWidget() const
+{
+  DUChainReadLocker lock;;
 
   Declaration* decl = dynamic_cast<KDevelop::Declaration*>(m_item.m_item.data());
-  if( !decl || !decl->context() )
+  if( !decl || !decl->context() ) {
     return 0;
+  }
 
-  return decl->context()->createNavigationWidget( decl, decl->topContext(), m_item.m_project.isEmpty() ? QString() : ("<small><small>" + i18n("Project") + ' ' + m_item.m_project + "<br>" + "</small></small>"));
+  return decl->context()->createNavigationWidget( decl, decl->topContext(),
+            m_item.m_project.isEmpty()
+                ? QString()
+                : ("<small><small>" + i18n("Project %1", m_item.m_project) + "<br></small></small>")
+  );
 }
 
-QIcon DUChainItemData::icon() const {
+QIcon DUChainItemData::icon() const
+{
   return QIcon();
 }
 
-DUChainItemDataProvider::DUChainItemDataProvider( IQuickOpen* quickopen, bool openDefinitions ) : m_quickopen(quickopen), m_openDefinitions(openDefinitions) {
+DUChainItemDataProvider::DUChainItemDataProvider( IQuickOpen* quickopen, bool openDefinitions )
+: m_quickopen(quickopen)
+, m_openDefinitions(openDefinitions)
+{
   reset();
 }
 
-void DUChainItemDataProvider::setFilterText( const QString& text ) {
+void DUChainItemDataProvider::setFilterText( const QString& text )
+{
   Base::setFilter( text );
 }
 
-uint DUChainItemDataProvider::itemCount() const {
+uint DUChainItemDataProvider::itemCount() const
+{
   return Base::filteredItems().count();
 }
 
-QList<KDevelop::QuickOpenDataPointer> DUChainItemDataProvider::data( uint start, uint end ) const {
-  if( end > (uint)Base::filteredItems().count() )
+uint DUChainItemDataProvider::unfilteredItemCount() const
+{
+  return Base::items().count();
+}
+
+QList<KDevelop::QuickOpenDataPointer> DUChainItemDataProvider::data( uint start, uint end ) const
+{
+  if( end > (uint)Base::filteredItems().count() ) {
     end = Base::filteredItems().count();
+  }
 
   QList<KDevelop::QuickOpenDataPointer> ret;
 
@@ -210,13 +250,16 @@ QList<KDevelop::QuickOpenDataPointer> DUChainItemDataProvider::data( uint start,
   return ret;
 }
 
-DUChainItemData* DUChainItemDataProvider::createData( const DUChainItem& item ) const {
-    return new DUChainItemData( item, m_openDefinitions );
+DUChainItemData* DUChainItemDataProvider::createData( const DUChainItem& item ) const
+{
+  return new DUChainItemData( item, m_openDefinitions );
 }
 
-QString DUChainItemDataProvider::itemText( const DUChainItem& data ) const {
+QString DUChainItemDataProvider::itemText( const DUChainItem& data ) const
+{
   return data.m_text;
 }
 
-void DUChainItemDataProvider::reset() {
+void DUChainItemDataProvider::reset()
+{
 }
