@@ -137,6 +137,8 @@ void QuickOpenModel::enableProviders( const QStringList& _items, const QStringLi
 
 void QuickOpenModel::textChanged( const QString& str )
 {
+  if( m_filterText == str )
+      return;
   m_filterText = str;
   foreach( const ProviderEntry& provider, m_providers )
     if( provider.enabled )
@@ -154,6 +156,14 @@ void QuickOpenModel::textChanged( const QString& str )
 }
 
 void QuickOpenModel::restart(bool keepFilterText)
+{
+    // make sure we do not restart recursivly which could lead to
+    // recursive loading of provider plugins e.g. (happened for the cpp plugin)
+    QMetaObject::invokeMethod(this, "restart_internal", Qt::QueuedConnection,
+                              Q_ARG(bool, keepFilterText));
+}
+
+void QuickOpenModel::restart_internal(bool keepFilterText)
 {
   if(!keepFilterText)
     m_filterText.clear();
@@ -222,6 +232,16 @@ int QuickOpenModel::rowCount( const QModelIndex& i ) const
   return count;
 }
 
+int QuickOpenModel::unfilteredRowCount() const
+{
+  int count = 0;
+  foreach( const ProviderEntry& provider, m_providers )
+    if( provider.enabled )
+      count += provider.provider->unfilteredItemCount();
+
+  return count;
+}
+
 int QuickOpenModel::columnCount() const
 {
   return 2;
@@ -380,7 +400,6 @@ QSet<IndexedString> QuickOpenModel::fileSet() const {
   return merged;
 }
 
-
 QTreeView* QuickOpenModel::treeView() const {
   return m_treeView;
 }
