@@ -95,8 +95,9 @@ struct AbstractFileManagerPlugin::Private {
 
     void removeFolder(ProjectFolderItem* folder);
 
-    QMap<IProject*, KDirWatch*> m_watchers;
-    QMap<IProject*, QList<FileManagerListJob*> > m_projectJobs;
+    QHash<IProject*, KDirWatch*> m_watchers;
+    QHash<IProject*, QList<FileManagerListJob*> > m_projectJobs;
+    QSet<QString> importFileNameFilter;
 };
 
 void AbstractFileManagerPlugin::Private::projectClosing(IProject* project)
@@ -159,6 +160,11 @@ void AbstractFileManagerPlugin::Private::addJobItems(FileManagerListJob* job,
             continue;
         }
 
+        // Simple equals-matching, fast and efficient and suitable for most cases
+        if( importFileNameFilter.contains( name ) ) {
+            continue;
+        }
+
         KUrl url = baseItem->url();
         url.addPath( name );
         if (entry.isDir()) {
@@ -594,6 +600,11 @@ KDirWatch* AbstractFileManagerPlugin::projectWatcher( IProject* project ) const
     return d->m_watchers.value( project, 0 );
 }
 
+void AbstractFileManagerPlugin::setImportFileNameFilter(const QStringList& filterNames)
+{
+    d->importFileNameFilter = filterNames.toSet();
+}
+
 //END Plugin
 
 #include "abstractfilemanagerplugin.moc"
