@@ -60,7 +60,7 @@ Boston, MA 02110-1301, USA.
 
 #include <config-kdevplatform.h>
 
-#if HAVE_KOMPARE
+#ifdef HAVE_KOMPARE
     #include "patchdocument.h"
 #endif
 
@@ -245,7 +245,7 @@ struct DocumentControllerPrivate {
             else
             {
                 //make sure the URL exists
-                if ( !url.isValid() || !KIO::NetAccess::exists( url, KIO::NetAccess::DestinationSide, 0 ) )
+                if ( !url.isValid() || !KIO::NetAccess::exists( url, KIO::NetAccess::SourceSide, ICore::self()->uiController()->activeMainWindow() ) )
                 {
                     kDebug() << "cannot find URL:" << url.url();
                     return 0;
@@ -301,7 +301,7 @@ struct DocumentControllerPrivate {
                     doc = new PartDocument(url, Core::self());
                 } else
                 {
-                    int openAsText = KMessageBox::questionYesNo(0, i18n("KDevelop could not find the editor for file '%1' of type %2.\nDo you want to open it as plain text?", url.fileName(), mimeType->name()), i18n("Could Not Find Editor"));
+                    int openAsText = KMessageBox::questionYesNo(0, i18n("KDevelop could not find the editor for file '%1' of type %2.\nDo you want to open it as plain text?", url.fileName(), mimeType->name()), i18nc("@title:window", "Could Not Find Editor"));
                     if (openAsText == KMessageBox::Yes)
                         doc = new TextDocument(url, Core::self(), _encoding);
                     else
@@ -565,7 +565,7 @@ DocumentController::DocumentController( QObject *parent )
 
     if(!(Core::self()->setupFlags() & Core::NoUi)) setupActions();
 
-#if HAVE_KOMPARE    
+#ifdef HAVE_KOMPARE
     registerDocumentForMimetype("text/x-patch", new PatchDocumentFactory);
 #endif
 }
@@ -802,7 +802,7 @@ bool KDevelop::DocumentController::saveSomeDocuments(const QList< IDocument * >
 {
     if (mode & IDocument::Silent) {
         foreach (IDocument* doc, modifiedDocuments(list)) {
-            if( !doc->save(mode) )
+            if( !DocumentController::isEmptyDocumentUrl(doc->url()) && !doc->save(mode) )
             {
                 if( doc )
                     qWarning() << "!! Could not save document:" << doc->url();
@@ -1096,7 +1096,7 @@ bool DocumentController::openDocumentsWithSplitSeparators( Sublime::AreaIndex* i
             foreach(QStringList group, groups)
                 ret &= openDocumentsWithSplitSeparators( index, group, isFirstView );
         }else{
-            while(index->isSplitted())
+            while(index->isSplit())
                 index = index->first();
             // Simply open the document into the area index
             IDocument* doc = Core::self()->documentControllerInternal()->openDocument(KUrl(urlsWithSeparators.front()),
@@ -1139,13 +1139,13 @@ bool DocumentController::openDocumentsWithSplitSeparators( Sublime::AreaIndex* i
     
     Qt::Orientation orientation = urlsWithSeparators[pickSeparator] == "/" ? Qt::Horizontal : Qt::Vertical;
     
-    if(!index->isSplitted())
+    if(!index->isSplit())
     {
         kDebug() << "splitting " << index << "orientation" << orientation << "to second" << activeViewToSecondChild;
         index->split(orientation, activeViewToSecondChild);
     }else{
         index->setOrientation(orientation);
-        kDebug() << "WARNING: Area is already splitted (shouldn't be)" << urlsWithSeparators;
+        kDebug() << "WARNING: Area is already split (shouldn't be)" << urlsWithSeparators;
     }
     
     openDocumentsWithSplitSeparators( index->first(), urlsWithSeparators.mid(0, pickSeparator) , isFirstView );
@@ -1154,12 +1154,12 @@ bool DocumentController::openDocumentsWithSplitSeparators( Sublime::AreaIndex* i
     
     // Clean up the child-indices, because document-loading may fail
     
-    if(!index->first()->viewCount() && !index->first()->isSplitted())
+    if(!index->first()->viewCount() && !index->first()->isSplit())
     {
         kDebug() << "unsplitting first";
         index->unsplit(index->first());
     }
-    else if(!index->second()->viewCount() && !index->second()->isSplitted())
+    else if(!index->second()->viewCount() && !index->second()->isSplit())
     {
         kDebug() << "unsplitting second";
         index->unsplit(index->second());
