@@ -35,6 +35,7 @@ Boston, MA 02110-1301, USA.
 #include <kio/netaccess.h>
 #include <kparts/mainwindow.h>
 #include <kactioncollection.h>
+#include <kpushbutton.h>
 
 #include "session.h"
 #include "core.h"
@@ -53,13 +54,14 @@ Boston, MA 02110-1301, USA.
 #include <QBoxLayout>
 #include <QTimer>
 #include <QStandardItemModel>
-#include <QTreeView>
+#include <QListView>
 #include <QHeaderView>
 #include <klockfile.h>
 #include <interfaces/idocumentcontroller.h>
 #include <ktexteditor/document.h>
 #include <sublime/area.h>
 #include <QLabel>
+#include <QLayout>
 #include <QDBusConnection>
 
 
@@ -99,7 +101,7 @@ static QStringList standardArguments()
         }else */
         if(arg.startsWith("-graphicssystem") || arg.startsWith("-style"))
         {
-            ret << "-" + arg;
+            ret << '-' + arg;
             if(a+1 < argc)
                 ret << QString::fromLocal8Bit(argv[a+1]);
         }
@@ -296,7 +298,7 @@ public:
     QString ownSessionDirectory() const
     {
         Q_ASSERT(activeSession);
-        return SessionController::sessionDirectory() + "/" + activeSession->id().toString();
+        return SessionController::sessionDirectory() + '/' + activeSession->id().toString();
     }
     
     void clearRecoveryDirectory()
@@ -397,7 +399,7 @@ private slots:
                             urlFile.open(QIODevice::ReadOnly);
                             KUrl originalFile(QString::fromUtf8(urlFile.readAll()));
                             
-                            QFile f(recoverySubDir.path() + "/" + QString("/%1_text").arg(num));
+                            QFile f(recoverySubDir.path() + '/' + QString("/%1_text").arg(num));
                             f.open(QIODevice::ReadOnly);
                             QString text = QString::fromUtf8(f.readAll());
                             
@@ -498,7 +500,7 @@ private slots:
                             urlFile.write(document->url().pathOrUrl().toUtf8());
                             urlFile.close();
                             
-                            QString textFilePath = recoveryCurrentDir.path() + "/" + QString("/%1_text").arg(num);
+                            QString textFilePath = recoveryCurrentDir.path() + '/' + QString("/%1_text").arg(num);
                             QFile f(textFilePath);
                             f.open(QIODevice::WriteOnly);
                             f.write(text.toUtf8());
@@ -565,8 +567,8 @@ SessionController::SessionController( QObject *parent )
     if (Core::self()->setupFlags() & Core::NoUi) return;
 
     KAction* action = actionCollection()->addAction( "new_session", this, SLOT(newSession()) );
-    action->setText( i18n("Start New Session") );
-    action->setToolTip( i18n("Start a new KDevelop instance with an empty session") );
+    action->setText( i18nc("@action:inmenu", "Start New Session") );
+    action->setToolTip( i18nc("@info:tooltip", "Start a new KDevelop instance with an empty session") );
     action->setIcon(KIcon("window-new"));
 
     action = actionCollection()->addAction( "rename_session", this, SLOT(renameSession()) );
@@ -680,7 +682,7 @@ QList< const KDevelop::Session* > SessionController::sessions() const
 Session* SessionController::createSession( const QString& name )
 {
     Session* s;
-    if(name.startsWith("{"))
+    if(name.startsWith('{'))
     {
         s = new Session( QUuid(name) );
     }else{
@@ -775,7 +777,7 @@ QList< SessionInfo > SessionController::availableSessionInfo()
         // TODO: Refactor the code here and in session.cpp so its shared
         SessionInfo si;
         si.uuid = id;
-        KSharedConfig::Ptr config = KSharedConfig::openConfig( sessiondir.absolutePath() + "/" + s +"/sessionrc" );
+        KSharedConfig::Ptr config = KSharedConfig::openConfig( sessiondir.absolutePath() + '/' + s +"/sessionrc" );
 
         QString desc = config->group( "" ).readEntry( "SessionName", "" );
         si.name = desc;
@@ -803,14 +805,14 @@ QString SessionController::sessionDirectory()
 
 QString SessionController::sessionDir()
 {
-    return sessionDirectory() + "/" + activeSession()->id().toString();
+    return sessionDirectory() + '/' + activeSession()->id().toString();
 }
 
 SessionController::LockSessionState SessionController::tryLockSession(QString id)
 {
     LockSessionState ret;
     
-    ret.lockFile = sessionDirectory() + "/" + id + "/lock";
+    ret.lockFile = sessionDirectory() + '/' + id + "/lock";
 
     if(!QFileInfo(ret.lockFile).exists())
     {
@@ -831,22 +833,50 @@ SessionController::LockSessionState SessionController::tryLockSession(QString id
 class SessionChooserDialog : public KDialog {
     Q_OBJECT
 public:
-    SessionChooserDialog(QTreeView* view, QStandardItemModel* model);
-    
+    SessionChooserDialog(QListView* view, QStandardItemModel* model);
+    bool eventFilter(QObject* object, QEvent* event);
+
 public Q_SLOTS:
     void updateState();
     void doubleClicked(QModelIndex);
+
+private Q_SLOTS:
+    void deleteButtonPressed();
+    void showDeleteButton();
+    void itemEntered(const QModelIndex& index);
+
 private:
+    QListView* m_view;
     QStandardItemModel* m_model;
     QTimer m_updateStateTimer;
+
+    QPushButton* m_deleteButton;
+    QTimer m_deleteButtonTimer;
+    int m_deleteCandidateRow;
 };
 
-SessionChooserDialog::SessionChooserDialog(QTreeView* view, QStandardItemModel* model) : m_model(model) {
+SessionChooserDialog::SessionChooserDialog(QListView* view, QStandardItemModel* model)
+    : m_view(view), m_model(model), m_deleteCandidateRow(-1)
+{
     m_updateStateTimer.setInterval(5000);
     m_updateStateTimer.setSingleShot(false);
     m_updateStateTimer.start();
     connect(&m_updateStateTimer, SIGNAL(timeout()), SLOT(updateState()));
     connect(view, SIGNAL(doubleClicked(QModelIndex)), SLOT(doubleClicked(QModelIndex)));
+    connect(view, SIGNAL(entered(QModelIndex)), SLOT(itemEntered(QModelIndex)));
+
+    m_deleteButton = new KPushButton(view->viewport());
+    m_deleteButton->setIcon(KIcon("edit-delete"));
+    m_deleteButton->setToolTip(i18nc("@info", "Delete session"));
+    m_deleteButton->hide();
+    connect(m_deleteButton, SIGNAL(clicked(bool)), SLOT(deleteButtonPressed()));
+
+    m_deleteButtonTimer.setInterval(500);
+    m_deleteButtonTimer.setSingleShot(true);
+    connect(&m_deleteButtonTimer, SIGNAL(timeout()), SLOT(showDeleteButton()));
+
+    view->setMouseTracking(true);
+    view->installEventFilter(this);
 }
 
 void SessionChooserDialog::doubleClicked(QModelIndex index)
@@ -866,18 +896,19 @@ void SessionChooserDialog::updateState() {
         if(session == i18n("Create New Session"))
             continue;
         
-        bool running = false;
-        QString state;
+        QString state, tooltip;
         SessionController::LockSessionState lockState = KDevelop::SessionController::tryLockSession(session);
         if(!lockState)
         {
-            state = i18n("[running, pid %1, app %2, host %3]", lockState.holderPid,
-                         lockState.holderApp, lockState.holderHostname);
-            running = true;
+            tooltip = i18n("Active session.\npid %1, app %2, host %3", lockState.holderPid, lockState.holderApp, lockState.holderHostname);
+            state = i18n("Running");
         }
         
-        if(m_model->item(row, 2))
+        if(m_model->item(row, 2)) {
+            m_model->item(row, 1)->setIcon(lockState ? KIcon("") : KIcon("media-playback-start"));
+            m_model->item(row, 1)->setToolTip(tooltip);
             m_model->item(row, 2)->setText(state);
+        }
     }
     
     m_updateStateTimer.start();
@@ -888,10 +919,9 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
     // The catalog hasn't been loaded yet
     KGlobal::locale()->insertCatalog("kdevplatform");
 
-    QTreeView* view = new QTreeView;
+    QListView* view = new QListView;
     QStandardItemModel* model = new QStandardItemModel(view);
     SessionChooserDialog dialog(view, model);
-    view->setRootIsDecorated(false);
     view->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
     QVBoxLayout layout(dialog.mainWidget());
@@ -903,6 +933,7 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
     model->setHeaderData(1, Qt::Horizontal, i18n("Contents"));
     model->setHeaderData(2, Qt::Horizontal,i18n("State"));
     view->setModel(model);
+    view->setModelColumn(1);
     layout.addWidget(view);
     
     int row = 0;
@@ -917,9 +948,7 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
             continue;
         }
 
-        bool running = false;
-        if(!KDevelop::SessionController::tryLockSession(si.uuid.toString()))
-            running = true;
+        bool running = KDevelop::SessionController::tryLockSession(si.uuid.toString());
         
         if(onlyRunning && !running)
             continue;
@@ -929,27 +958,24 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
         
         model->setItem(row, 0, new QStandardItem(si.uuid.toString()));
         model->setItem(row, 1, new QStandardItem(si.description));
-        
-        QString state;
-        
-        model->setItem(row, 2, new QStandardItem(""));
+        model->setItem(row, 2, new QStandardItem);
         
         if(defaultRow == row && running)
             ++defaultRow;
         
         ++row;
     }
-    
-    if(!onlyRunning)
-        model->setItem(row, 0, new QStandardItem(i18n("Create New Session")));
+
+    int cnsRow = row;
+    if(!onlyRunning) {
+        model->setItem(row, 0, new QStandardItem);
+        model->setItem(row, 1, new QStandardItem(KIcon("window-new"), i18n("Create New Session")));
+    }
 
     dialog.updateState();
+    dialog.mainWidget()->layout()->setContentsMargins(0,0,0,0);
     
     view->selectionModel()->setCurrentIndex(model->index(defaultRow, 0), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
-    
-    view->resizeColumnToContents(0);
-    view->resizeColumnToContents(1);
-    view->resizeColumnToContents(2);
     view->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     ///@todo We need a way to get a proper size-hint from the view, but unfortunately, that only seems possible after the view was shown.
     dialog.setInitialSize(QSize(900, 600));
@@ -962,19 +988,83 @@ QString SessionController::showSessionChooserDialog(QString headerText, bool onl
     QModelIndex selected = view->selectionModel()->currentIndex();
     if(selected.isValid())
     {
-        selected = selected.sibling(selected.row(), 0);
-        QString ret = selected.data().toString();
-        if(ret == i18n("Create New Session"))
-        {
+        QString ret;
+        if( selected.row() == cnsRow ) {
             qsrand(QDateTime::currentDateTime().toTime_t());
             ret = QUuid::createUuid().toString();
+        } else {
+            selected = selected.sibling(selected.row(), 0);
+            ret = selected.data().toString();
         }
         return ret;
     }
-    
+
     return QString();
 }
 
+void SessionChooserDialog::itemEntered(const QModelIndex& index)
+{
+    // The last row says "Create new session", we don't want to delete that
+    if(index.row() == m_model->rowCount()-1) {
+        m_deleteButton->hide();
+        m_deleteButtonTimer.stop();
+        return;
+    }
+
+    // align the delete-button to stay on the right border of the item
+    // we need the right most column's index
+    QModelIndex in = m_model->index( index.row(), 1 );
+    const QRect rect = m_view->visualRect(in);
+    m_deleteButton->resize(rect.height(), rect.height());
+    
+    QPoint p(rect.right() - m_deleteButton->size().width(), rect.top()+rect.height()/2-m_deleteButton->height()/2);
+    m_deleteButton->move(p);
+
+    m_deleteCandidateRow = index.row();
+    m_deleteButtonTimer.start();
+}
+
+void SessionChooserDialog::showDeleteButton()
+{
+    m_deleteButton->show();
+}
+
+bool SessionChooserDialog::eventFilter(QObject* object, QEvent* event)
+{
+    if(object == m_view && event->type() == QEvent::Leave ) {
+        m_deleteButtonTimer.stop();
+        m_deleteButton->hide();
+    }
+
+    return false;
+}
+
+
+void SessionChooserDialog::deleteButtonPressed()
+{
+    if(m_deleteCandidateRow == -1)
+        return;
+
+    const QString text = i18nc("@info", "The session and all contained settings will be deleted. The projects will stay unaffected. Do you really want to continue?");
+    const QString caption = i18nc("@title", "Delete Session");
+    const KGuiItem deleteItem(i18nc("@action:button", "Delete"), KIcon("edit-delete"));
+    const KGuiItem cancelItem(i18nc("@action:button", "Cancel"), KIcon("dialog-cancel"));
+
+    if(KMessageBox::warningYesNo(this, text, caption, deleteItem, cancelItem) == KMessageBox::Yes) {
+        QModelIndex index = m_model->index(m_deleteCandidateRow, 0);
+        QStandardItem *item = m_model->itemFromIndex(index);
+        const QString uuid = item->text();
+
+        //FIXME: What about running sessions?
+        KDevelop::Session session( uuid );
+        session.deleteFromDisk();
+
+        m_model->removeRows( m_deleteCandidateRow, 1 );
+        m_deleteCandidateRow = -1;
+    }
+}
+
+
 QString SessionController::sessionName()
 {
     if(!activeSession())
