@@ -30,6 +30,7 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/iplugincontroller.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <language/interfaces/ilanguagesupport.h>
+#include <language/codegen/coderepresentation.h>
 #include <interfaces/isourceformatter.h>
 #include "core.h"
 #include <ktexteditor/view.h>
@@ -248,7 +249,7 @@ QString SourceFormatterController::addModelineForCurrentLang(QString input, cons
 			os <<  modeline;
 			foreach(QString s, optionList) {
 				if (knownOptions.indexIn(s) < 0) { // unknown option, add it
-					if(s.startsWith(" "))
+					if(s.startsWith(' '))
 						s=s.mid(1);
 					os << s << ";";
 					kDebug() << "Found unknown option: " << s << endl;
@@ -304,15 +305,6 @@ void SourceFormatterController::beautifySource()
 	if (view && view->selection())
 		has_selection = true;
 
-	//NOTE: this is ugly, but otherwise kate might remove tabs again :-/
-	// see also: https://bugs.kde.org/show_bug.cgi?id=291074
-	KTextEditor::ConfigInterface* iface = qobject_cast<KTextEditor::ConfigInterface*>(doc->textDocument());
-	QVariant oldReplaceTabs;
-	if (iface) {
-		oldReplaceTabs = iface->configValue("replace-tabs");
-		iface->setConfigValue("replace-tabs", false);
-	}
-
 	if (has_selection) {
 		QString original = view->selectionText();
 
@@ -324,13 +316,15 @@ void SourceFormatterController::beautifySource()
 		if (!original.endsWith('\n')  && output.endsWith('\n'))
 			output.resize(output.length() - 1);
 		//there was a selection, so only change the part of the text related to it
-		doc->textDocument()->replaceText(view->selectionRange(), output);
+			
+		// We don't use KTextEditor::Document directly, because CodeRepresentation transparently works
+		// around a possible tab-replacement incompatibility between kate and kdevelop
+		DynamicCodeRepresentation::Ptr code = DynamicCodeRepresentation::Ptr::dynamicCast( KDevelop::createCodeRepresentation( IndexedString( doc->url() ) ) );
+		Q_ASSERT( code );
+		code->replace( view->selectionRange(), original, output );
 	} else {
 		formatDocument(doc, formatter, mime);
 	}
-	if (iface) {
-		iface->setConfigValue("replace-tabs", oldReplaceTabs);
-	}
 }
 
 void SourceFormatterController::beautifyLine()
@@ -353,28 +347,37 @@ void SourceFormatterController::beautifyLine()
 	const KTextEditor::Cursor cursor = tDoc->activeView()->cursorPosition();
 	const QString line = tDoc->line(cursor.line());
 	const QString prev = tDoc->text(KTextEditor::Range(0, 0, cursor.line(), 0));
-	const QString post = "\n" + tDoc->text(KTextEditor::Range(KTextEditor::Cursor(cursor.line() + 1, 0), tDoc->documentEnd()));
+	const QString post = '\n' + tDoc->text(KTextEditor::Range(KTextEditor::Cursor(cursor.line() + 1, 0), tDoc->documentEnd()));
 	
 	const QString formatted = formatter->formatSource(line, doc->url(), mime, prev, post);
-	tDoc->replaceText(KTextEditor::Range(cursor.line(), 0, cursor.line(), line.length()), formatted);
+	
+	// We don't use KTextEditor::Document directly, because CodeRepresentation transparently works
+	// around a possible tab-replacement incompatibility between kate and kdevelop
+	DynamicCodeRepresentation::Ptr code = DynamicCodeRepresentation::Ptr::dynamicCast( KDevelop::createCodeRepresentation( IndexedString( doc->url() ) ) );
+	Q_ASSERT( code );
+	code->replace( KTextEditor::Range(cursor.line(), 0, cursor.line(), line.length()), line, formatted );
+	
 	// advance cursor one line
 	tDoc->activeView()->setCursorPosition(KTextEditor::Cursor(cursor.line() + 1, 0));
 }
 
 void SourceFormatterController::formatDocument(KDevelop::IDocument *doc, ISourceFormatter *formatter, const KMimeType::Ptr &mime)
 {
-	KTextEditor::Document *textDoc = doc->textDocument();
+	// We don't use KTextEditor::Document directly, because CodeRepresentation transparently works
+	// around a possible tab-replacement incompatibility between kate and kdevelop
+	CodeRepresentation::Ptr code = KDevelop::createCodeRepresentation( IndexedString( doc->url() ) );
 
 	KTextEditor::Cursor cursor = doc->cursorPosition();
-	QString text = formatter->formatSource(textDoc->text(), doc->url(), mime);
+	QString text = formatter->formatSource(code->text(), doc->url(), mime);
 	text = addModelineForCurrentLang(text, doc->url(), mime);
-	textDoc->setText(text);
+	code->setText(text);
+	
 	doc->setCursorPosition(cursor);
 }
 
 void SourceFormatterController::settingsChanged()
 {
-	if( configuration().readEntry( SourceFormatterController::kateOverrideIndentationConfigKey, true ) )
+	if( configuration().readEntry( SourceFormatterController::kateOverrideIndentationConfigKey, false ) )
 		foreach( KDevelop::IDocument* doc, ICore::self()->documentController()->openDocuments() )
 			adaptEditorIndentationMode( doc, formatterForUrl(doc->url()) );
 }
@@ -393,7 +396,7 @@ void SourceFormatterController::settingsChanged()
 
 void SourceFormatterController::adaptEditorIndentationMode(KDevelop::IDocument *doc, ISourceFormatter *formatter, bool ignoreModeline )
 {
-	if( !formatter  || !configuration().readEntry( SourceFormatterController::kateOverrideIndentationConfigKey, true ) || !doc->isTextDocument() )
+	if( !formatter  || !configuration().readEntry( SourceFormatterController::kateOverrideIndentationConfigKey, false ) || !doc->isTextDocument() )
 		return;
 
 	KTextEditor::Document *textDoc = doc->textDocument();
