@@ -72,7 +72,7 @@ WorkingSet::WorkingSet( const KDevelop::WorkingSet& rhs ) : QObject()
 
 void WorkingSet::saveFromArea( Sublime::Area* a, Sublime::AreaIndex * area, KConfigGroup setGroup, KConfigGroup areaGroup )
 {
-    if (area->isSplitted()) {
+    if (area->isSplit()) {
         setGroup.writeEntry("Orientation", area->orientation() == Qt::Horizontal ? "Horizontal" : "Vertical");
 
         if (area->first()) {
@@ -176,7 +176,11 @@ QStringList WorkingSet::fileList() const
 void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex) {
     PushValue<bool> enableLoading(m_loading, true);
 
-    DisableMainWindowUpdatesFromArea updatesDisabler(area);
+    /// We cannot disable the updates here, because (probably) due to a bug in Qt,
+    /// which causes the updates to stay disabled forever after some complex operations
+    /// on the sub-views. This could be reproduced by creating two working-sets with complex
+    /// split-view configurations and switching between them. Re-enabling the updates doesn't help.
+//     DisableMainWindowUpdatesFromArea updatesDisabler(area);
 
     kDebug() << "loading working-set" << m_id << "into area" << area;
     
@@ -194,7 +198,13 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
     KConfigGroup areaGroup = setConfig.group(m_id + '|' + area->title());
 
     loadToArea(area, areaIndex, setGroup, areaGroup, recycle);
-
+    
+    // Delete views which were not recycled
+    kDebug() << "deleting " << recycle.size() << " old views";
+    qDeleteAll( recycle.values() );
+    
+    area->setActiveView(0);
+    
     //activate view in the working set
     /// @todo correctly select one out of multiple equal views
     QString activeView = areaGroup.readEntry("Active View", QString());
@@ -205,14 +215,21 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex)
         }
     }
     
-    // Delete views which were not recycled
-    kDebug() << "deleting " << recycle.size() << " old views";
-    qDeleteAll( recycle.values() );
+    if( !area->activeView() && area->views().size() )
+        area->setActiveView( area->views()[0] );
+    
+    if( area->activeView() ) {
+        foreach(Sublime::MainWindow* window, Core::self()->uiControllerInternal()->mainWindows()) {
+                if(window->area() == area) {
+                    window->activateView( area->activeView() );
+                }
+        }
+    }
 }
 
 void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, KConfigGroup setGroup, KConfigGroup areaGroup, QMultiMap<QString, Sublime::View*>& recycle)
 {
-    Q_ASSERT( !areaIndex->isSplitted() );
+    Q_ASSERT( !areaIndex->isSplit() );
     if (setGroup.hasKey("Orientation")) {
         QStringList subgroups = setGroup.groupList();
         /// @todo also save and restore the ratio
@@ -221,7 +238,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
 //             kDebug() << "has zero, split:" << split;
 
             Qt::Orientation orientation = setGroup.readEntry("Orientation", "Horizontal") == "Vertical" ? Qt::Vertical : Qt::Horizontal;
-            if(!areaIndex->isSplitted()){
+            if(!areaIndex->isSplit()){
                 areaIndex->split(orientation);
             }else{
                 areaIndex->setOrientation(orientation);
@@ -230,11 +247,17 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
             loadToArea(area, areaIndex->first(), KConfigGroup(&setGroup, "0"), KConfigGroup(&areaGroup, "0"), recycle);
 
             loadToArea(area, areaIndex->second(), KConfigGroup(&setGroup, "1"), KConfigGroup(&areaGroup, "1"), recycle);
+            
+            if( areaIndex->first()->viewCount() == 0 )
+                areaIndex->unsplit(areaIndex->first());
+            else if( areaIndex->second()->viewCount() == 0 )
+                areaIndex->unsplit(areaIndex->second());
         }
     } else {
         
         //Load all documents from the workingset into this areaIndex
         int viewCount = setGroup.readEntry("View Count", 0);
+        QMap<int, Sublime::View*> createdViews;
         for (int i = 0; i < viewCount; ++i) {
             QString type = setGroup.readEntry(QString("View %1 Type").arg(i), "");
             QString specifier = setGroup.readEntry(QString("View %1").arg(i), "");
@@ -254,6 +277,7 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
             if (document) {
                 Sublime::View* view = document->createView();
                 area->addView(view, areaIndex, previousView);
+                createdViews[i] = view;
             } else {
                 kWarning() << "Unable to create view of type " << type;
             }
@@ -263,8 +287,8 @@ void WorkingSet::loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex,
         for (int i = 0; i < viewCount; ++i)
         {
             QString state = areaGroup.readEntry(QString("View %1 State").arg(i));
-            if (state.length())
-                areaIndex->views()[i]->setState(state);
+            if (state.length() && createdViews.contains(i))
+                createdViews[i]->setState(state);
         }
     }
 }
