@@ -26,20 +26,67 @@
 #include <shell/plugincontroller.h>
 #include <shell/partcontroller.h>
 #include <shell/projectcontroller.h>
+#include <interfaces/isession.h>
 #include "../shell/core_p.h"
 
+#include <QCoreApplication>
+#include <QTest>
+
+#include <KParts/MainWindow>
+
 namespace KDevelop
 {
 
 TestCore::TestCore()
  : Core( new CorePrivate(this) )
 {
-    KDevelop::Core::m_self = this;
+    Core::m_self = this;
 }
 
 void TestCore::initialize( Core::Setup mode, const QString& session )
 {
+    qRegisterMetaType<KUrl::List>("KUrl::List");
+
+    if (!Core::m_self) {
+        new TestCore;
+    }
+
+    TestCore* core = dynamic_cast<TestCore*>(Core::m_self);
+    Q_ASSERT(core);
+    core->initializeNonStatic(mode, session);
+
+    if (mode == Default) {
+        // we don't want the window to be visible, hide it
+        // the unit tests should work anyways
+        core->uiController()->activeMainWindow()->hide();
+    }
+}
+
+void TestCore::initializeNonStatic(Core::Setup mode, const QString& _session)
+{
+    QString session = _session;
+    if (_session.isEmpty()) {
+        // use a distinct session name for unit test sessions
+        // they are temporary (see below) but still - we want to make sure
+        session = "test-" + qAppName();
+    }
+
     d->initialize( mode, session );
+
+    if (_session.isEmpty()) {
+        activeSession()->setTemporary(true);
+    }
+}
+
+void TestCore::shutdown()
+{
+    if (self()) {
+        // trigger eventloop to handle Queued connections
+        // before entering cleanup
+        // this can fix random crashes under certain conditions
+        QTest::qWait(1);
+        self()->shutdown();
+    }
 }
 
 void TestCore::setSessionController( SessionController* ctrl )
