@@ -240,7 +240,10 @@ void DVcsJob::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
     d->status = JobSucceeded;
 
-    if (exitStatus != QProcess::NormalExit || exitCode != 0)
+    if (exitStatus == QProcess::CrashExit)
+        slotProcessError(QProcess::Crashed);
+
+    else if (exitCode != 0)
         slotProcessError(QProcess::UnknownError);
 
     d->model->appendLine(i18n("Command exited with value %1.", exitCode));
